# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

#' mtclim
#' 
#' This is the core mtclim function 
#' @importFrom Rcpp evalCpp
#' @useDynLib RBBGCMuso
#' @param iniFile is the name of the inifile
#' @keywords internal
#' @export 
mtclim <- function(iniFile) {
    invisible(.Call('_RBBGCMuso_mtclim', PACKAGE = 'RBBGCMuso', iniFile))
}

getWritePositions <- function(a) {
    .Call('_RBBGCMuso_getWritePositions', PACKAGE = 'RBBGCMuso', a)
}

#' changeMusoC
#' 
#' This function is fastly randomize values based on min and max values
#' @importFrom Rcpp evalCpp
#' @useDynLib RBBGCMuso
#' @param inFile is the big matrix
#' @param outFile is the small matrix
#' @export
changeMusoC <- function(inFile, outFile, inMat) {
    invisible(.Call('_RBBGCMuso_changeMusoC', PACKAGE = 'RBBGCMuso', inFile, outFile, inMat))
}

randTypeOne <- function(m) {
    .Call('_RBBGCMuso_randTypeOne', PACKAGE = 'RBBGCMuso', m)
}

randTypeTwo <- function(m) {
    .Call('_RBBGCMuso_randTypeTwo', PACKAGE = 'RBBGCMuso', m)
}

#' musoRandomizer
#' 
#' This function is fastly randomize values based on min and max values,
#' and row indexes.
#' @importFrom Rcpp evalCpp
#' @useDynLib RBBGCMuso
#' @param A is the big matrix
#' @param B is the small matrix
#' @export
musoRandomizer <- function(A, B) {
    .Call('_RBBGCMuso_musoRandomizer', PACKAGE = 'RBBGCMuso', A, B)
}

